- **`print(text="", mode=None)`**
    - `text` (str, optional): text, which will be written to he conso.
    - `mode` (str, optional): basicly, defines text color, here are all the colors:
        - `"d"` — green (debug).
        - `"w"` — yellow (warning).
        - `"e"` — red (error).
        - `"c"` — purple (critical).
        - `"i"` — blue (info).

- **`debug(message)`**
    - `message` (str): message, which will be written to the console in green color.

- **`info(message)`**
    - `message` (str): message, which will be written to the console in blue color.

- **`warning(message)`**
    - `message` (str): message, which will be written to the console in yellow color.

- **`error(message)`**
    - `message` (str): message, which will be written to the console in red color.

- **`critical(message, exit=1)`**
    - `message` (str): message, which will be written to the console in purple color.
    - `exit` (int, optional): exit code (default: `1`). If `exit` > 0, programm won't exit.